@@ -280,7 +280,7 @@ void search_thread_run(long t)
           strcpy(si_plus[t].qsequence, qseq);
           
           /* get progress as amount of input file read */
-          int progress = query_getfilepos();
+          unsigned long progress = query_getfilepos();
 
           /* let other threads read input */
           pthread_mutex_unlock(&mutex_input);
@@ -583,8 +583,13 @@ void usearch_global(char * cmdline, char * progheader)
 
   query_close();
 
-  fprintf(stderr, "Matching query sequences: %d of %d (%.2f%%)\n", 
-          qmatches, queries, 100.0 * qmatches / queries);
+  if (!opt_quiet)
+    fprintf(stderr, "Matching query sequences: %d of %d (%.2f%%)\n", 
+            qmatches, queries, 100.0 * qmatches / queries);
+
+  if (opt_log)
+    fprintf(fp_log, "Matching query sequences: %d of %d (%.2f%%)\n", 
+            qmatches, queries, 100.0 * qmatches / queries);
 
   if (opt_dbmatched || opt_dbnotmatched)
     {
